@@ -6,6 +6,14 @@ from time import sleep
 from pypif import pif
 from pypif.util.case import keys_to_snake_case
 from citrination_client.util.quote_finder import quote
+from citrination_client.search.pif.query.pif_query import PifQuery
+from citrination_client.search.pif.query.core.field_operation import FieldOperation
+from citrination_client.search.pif.query.core.filter import Filter
+from citrination_client.search.pif.query.core.property_query import PropertyQuery
+from citrination_client.search.pif.query.core.reference_query import ReferenceQuery
+from citrination_client.search.pif.query.core.system_query import SystemQuery
+from citrination_client.search.pif.query.chemical.chemical_field_operation import  ChemicalFieldOperation
+from citrination_client.search.pif.query.chemical.chemical_filter import ChemicalFilter
 from citrination_client.search.pif.result.pif_search_result import PifSearchResult
 
 
@@ -55,18 +63,131 @@ class CitrinationClient(object):
             raise RuntimeError('Received ' + str(response.status_code) + ' response: ' + str(response.reason))
         return PifSearchResult(**keys_to_snake_case(response.json()['results']))
 
+    def simple_chemical_search(self, name=None, chemical_formula=None, property_name=None, property_value=None,
+                               property_min=None, property_max=None, property_units=None, reference_doi=None,
+                               include_datasets=[], exclude_datasets=[], from_index=None, size=None):
+        """
+        Run a query against Citrination. This method generates a :class:`.PifQuery` object using the supplied arguments.
+        All arguments that accept lists have logical OR's on the queries that they generate. This means that, for
+        example, simple_chemical_search(name=['A', 'B']) will match records that have name equal to 'A' or 'B'.
+
+        Results will be pulled into the extracted field of the :class:`.PifSearchHit` objects that are returned. The
+        name will appear under the key "name", chemical formula under "chemical_formula", property name under
+        "property_name", value of the property under "property_value", units of the property under "property_units",
+        and reference DOI under "reference_doi".
+
+        This method is only meant for execution of very simple queries. More complex queries must use the search method
+        that accepts a :class:`.PifQuery` object.
+
+        :param name: One or more strings with the names of the chemical system to match.
+        :param chemical_formula:  One or more strings with the chemical formulas to match.
+        :param property_name: One or more strings with the names of the property to match.
+        :param property_value: One or more strings or numbers with the exact values to match.
+        :param property_min: A single string or number with the minimum value to match.
+        :param property_max: A single string or number with the maximum value to match.
+        :param property_units: One or more strings with the property units to match.
+        :param reference_doi: One or more strings with the DOI to match.
+        :param include_datasets: One or more integers with dataset IDs to match.
+        :param exclude_datasets: One or more integers with dataset IDs that must not match.
+        :param from_index: Index of the first record to match.
+        :param size: Total number of records to return.
+        :return: :class:`.PifSearchResult` object with the results of the query.
+        """
+        system_query = SystemQuery()
+        system_query.names = FieldOperation(
+            extract_as='name',
+            filter=[Filter(equal=i) for i in self._get_list(name)])
+        system_query.chemical_formula = ChemicalFieldOperation(
+            extract_as='chemical_formula',
+            filter=[ChemicalFilter(equal=i) for i in self._get_list(chemical_formula)])
+        system_query.references = ReferenceQuery(doi=FieldOperation(
+            extract_as='reference_doi',
+            filter=[Filter(equal=i) for i in self._get_list(reference_doi)]))
+
+        # Generate the parts of the property query
+        property_name_query = FieldOperation(
+            extract_as='property_name',
+            filter=[Filter(equal=i) for i in self._get_list(property_name)])
+        property_units_query = FieldOperation(
+            extract_as='property_units',
+            filter=[Filter(equal=i) for i in self._get_list(property_units)])
+        property_value_query = FieldOperation(
+            extract_as='property_value',
+            filter=[])
+        for i in self._get_list(property_value):
+            property_value_query.filter.append(Filter(equal=i))
+        if property_min is not None or property_max is not None:
+            property_value_query.filter.append(Filter(min=property_min, max=property_max))
+
+        # Generate the full property query
+        system_query.properties = PropertyQuery(
+            name=property_name_query,
+            value=property_value_query,
+            units=property_units_query)
+
+        # Run the query
+        query = PifQuery(
+            system=system_query,
+            from_index=from_index,
+            size=size,
+            score_relevance=True,
+            include_datasets=include_datasets,
+            exclude_datasets=exclude_datasets)
+        return self.search(query)
+
+    @staticmethod
+    def _get_list(values):
+        """
+        Helper method that wraps values in a list. If the input is a list then it is returned. If the input is None
+        then an empty list is returned. For anything else, the input value is wrapped as a single-element list.
+
+        :param values: Value to make sure exists in a list.
+        :return: List with the input values.
+        """
+        if values is None:
+            return []
+        elif isinstance(values, list):
+            return values
+        else:
+            return [values]
+
+    def predict(self, model_name, candidates):
+        """
+        Predict endpoint
+        :param model_name: The model path
+        :param candidates: A list of candidates
+        :return: list of predicted candidates as a map {property: [value, uncertainty]}
+        """
+
+        # If a single candidate is passed, wrap in a list for the user
+        if not isinstance(candidates, list):
+            candidates = [candidates]
+
+        url = self._get_predict_url(model_name)
+        body = pif.dumps(
+            {"predictionRequest": {"predictionSource": "scalar", "usePrior": True, "candidates": candidates}}
+        )
+
+        response = requests.post(url, data=body, headers=self.headers)
+        if response.status_code != requests.codes.ok:
+            raise RuntimeError('Received ' + str(response.status_code) + ' response: ' + str(response.reason))
+
+        return response.json()
+
+    def _get_predict_url(self, model_name):
+        return self.api_url + '/csv_to_models/' + model_name + '/predict'
+
     def upload_file(self, file_path, data_set_id, root_path=None):
         """
         Upload file to Citrination.
 
         :param file_path: File path to upload.
         :param data_set_id: The dataset id to upload the file to.
-        :return: Response object or None if the file was not uploaded.
+        :return: Response object or return code if the file was not uploaded.
         """
         if os.path.isdir(str(file_path)):
             for path, subdirs, files in os.walk(file_path):
                 for name in files:
-                    root = None
                     if root_path:
                        root = root_path
                     else:
@@ -83,7 +204,7 @@ class CitrinationClient(object):
 
             r = requests.post(url, data=json.dumps(file_data), headers=self.headers)
             if r.status_code == 200:
-                j = json.loads(r.content)
+                j = json.loads(r.content.decode('utf-8'))
                 s3url = self._get_s3_presigned_url(j)
                 with open(file_path, 'rb') as f:
                     r = requests.put(s3url, data=f)
@@ -100,7 +221,9 @@ class CitrinationClient(object):
                                    "status": r.status_code}
                         return json.dumps(message)
             else:
-                return None
+                message = {"message": "Upload failed.",
+                                   "status": r.status_code}
+                return json.dumps(message)
 
     def get_dataset_files(self, dataset_id, latest = False):
         """
@@ -157,7 +280,7 @@ class CitrinationClient(object):
         """
         result = requests.get(url, headers=self.headers)
         if result.status_code == 200:
-            return json.loads(result.content)
+            return json.loads(result.content.decode('utf-8'))
         else:
             print('An error ocurred during this action: ' + str(result.status_code) + ' - ' + str(result.reason) )
             return False
