@@ -1,6 +1,5 @@
 from citrination_client.search.pif.query.core.value_query import ValueQuery
 from citrination_client.search.pif.query.core.field_operation import FieldOperation
-from citrination_client.search.pif.query.core.file_reference_query import FileReferenceQuery
 
 
 class PropertyQuery(ValueQuery):
@@ -9,7 +8,8 @@ class PropertyQuery(ValueQuery):
     """
 
     def __init__(self, file=None, conditions=None, data_type=None, name=None, value=None, units=None,
-                 units_normalization=None, logic=None, tags=None, length=None, offset=None):
+                 units_normalization=None, logic=None, extract_as=None, extract_all=None,
+                 extract_when_missing=None, tags=None, length=None, offset=None):
         """
         Constructor.
 
@@ -21,32 +21,24 @@ class PropertyQuery(ValueQuery):
         :param units: One or more :class:`FieldOperation` operations against the units field.
         :param units_normalization: :class:`UnitsNormalization` object for normalizing units.
         :param logic: Logic for this filter. Must be equal to one of "MUST", "MUST_NOT", "SHOULD", or "OPTIONAL".
+        :param extract_as: String with the alias to save this field under.
+        :param extract_all: Boolean setting whether all values in an array should be extracted.
+        :param extract_when_missing: Any valid JSON-supported object or PIF object. This value is returned when a value
+        is missing that should be extracted (and the overall query is still satisfied).
         :param tags: One or more :class:`FieldOperation` operations against the tags field.
         :param length: One or more :class:`FieldOperation` operations against the length field.
         :param offset: One or more :class:`FieldOperation` operations against the offset field.
         """
-        super(PropertyQuery, self).__init__(name=name, value=value, units=units,
-                                            units_normalization=units_normalization, logic=logic, tags=tags,
+        super(PropertyQuery, self).__init__(name=name, value=value, file=file, units=units,
+                                            units_normalization=units_normalization, logic=logic,
+                                            extract_as=extract_as, extract_all=extract_all,
+                                            extract_when_missing=extract_when_missing, tags=tags,
                                             length=length, offset=offset)
-        self._file = None
-        self.file = file
         self._conditions = None
         self.conditions = conditions
         self._data_type = None
         self.data_type = data_type
 
-    @property
-    def file(self):
-        return self._file
-
-    @file.setter
-    def file(self, file):
-        self._file = self._get_object(FileReferenceQuery, file)
-
-    @file.deleter
-    def file(self):
-        self._file = None
-
     @property
     def conditions(self):
         return self._conditions
